<?php

namespace Drupal\twig_placeholders\Twig;

use Drupal\Core\Template\Attribute;
use Drupal\twig_placeholders\Service\LoremIpsumGenerator;
use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;

/**
 * Provides a Twig function for generating placeholder table data.
 */
class TableDataExtension extends AbstractExtension {
  /**
   * The Lorem Ipsum generator service.
   *
   * @var \Drupal\twig_placeholders\Service\LoremIpsumGenerator
   */
  protected LoremIpsumGenerator $generator;

  /**
   * Constructs a TableDataExtension object.
   *
   * @param \Drupal\twig_placeholders\Service\LoremIpsumGenerator $generator
   *   The Lorem Ipsum generator service.
   */
  public function __construct(LoremIpsumGenerator $generator) {
    $this->generator = $generator;
  }

  /**
   * {@inheritdoc}
   */
  public function getFunctions(): array {
    return [
      new TwigFunction('tp_table_data', [$this, 'generateTableData']),
    ];
  }

  /**
   * Generates placeholder table data.
   *
   * @param int $num_rows
   *   Number of rows (default: 10).
   * @param int $num_cols
   *   Number of columns (default: 4).
   *
   * @return array<array<string, mixed>>
   *   Structured array representing table rows and cells.
   */
  public function generateTableData(int $num_rows = 10, int $num_cols = 4): array {
    $rows = [];

    for ($i = 0; $i < $num_rows; $i++) {
      $cells = [];

      for ($j = 0; $j < $num_cols; $j++) {
        $cells[] = [
          'tag' => 'td',
          'attributes' => new Attribute(),
          'content' => $this->generator->generate(2),
        ];
      }

      $rows[] = [
        'attributes' => new Attribute(),
        'cells' => $cells,
      ];
    }

    return $rows;
  }

}
